from setuptools import setup

setup(
    name='inferase',
    version='0.0.0',
    description='automated inference of integration and edits',
    long_description='',
    url='',
    author='Ayaan Hossain',
    author_email='',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)